How To - Schritt für Schritt Anleitung — excel2moodle 0.5.0 documentation

# How To - Schritt für Schritt Anleitung

In dieser How-To Anleitung werden unterschiedliche Arbeiten mit dem Excel2moodle Schritt für Schritt gezeigt. Die folgenden Prozesse sind dokumentiert

Die folgenden Prozesse sind noch nicht dokumentiert:

> - Fragen in der Tabellenkalkulation erstellen

Auch wenn manche Arbeitsschritte noch nicht als How-To dargestellt sind, lassen sich die wichtigsten Informationen der User Reference entnehmen oder aus den Fragenbeispiele ableiten.

## Excel2moodle unter Windows installieren

### Quick How-To

Die folgenden Befehle müssen nacheinander in der Powershell ausgeführt werden, um excel2moodle zu installieren: (Es sind keine Admin Privilegien notwendig)

    winget install python
    powershell -ExecutionPolicy ByPass -c "irm https://astral.sh/uv/install.ps1 | iex"
    (nun ein Neustart der Powershell notwendig)
    uv tool install excel2moodle

Nun kann über `excel2moodle` in der Powershell das programm gestartet werden.

### Das erläuterte How-To

excel2moodle ist ein Python Paket und im Python Packaging Index unter pypi.org verfügbar und über den Paketmanager von Python installierbar. Voraussetzung für die Installation von excel2moodle ist daher eine Python Installation.

Um excel2moodle nutzten zu können sind die folgenden Schritte Notwendig

#### 1. Installation von Python

Der Python Interpreter kann über den Microsoft Store installiert werden. Über die PowerShell geht das wie folgt:

    winget install python

Es ist die Version python 3.13 empfohlen.

Note

Alternativ kann der Python Interpreter über python.org/downloas/winows heruntergeladen und dann die python3.XX.XX.exe installiert werden Wichtig ist, während der Installation den Haken bei Add python.exe to PATH zu setzen.

Sobald Python installiert ist, kann es in der PowerShell aufgerufen werden mit einem (oder mehreren) der folgenden Befehle:

- py (Nach der Installation über den offiziellen Python-Installer)

- python

- python3 (Nach der Installation über den Microsoft Store)

Note

Im folgenden wird immer der Befehl py verwendet. Der kann wenn notwendig mit python3 ersetzt werden.

#### 2. Installation von uv

Es ist sehr zu empfehlen excel2moodle über den neuen Python Paketmanager uv zu installieren, da dies sicherstellt, dass die Abhängigkeiten von excel2moodle nicht mit Abhängigkeiten von anderen python Paketen kollidieren.

In der PowerShell folgendes ausführen:

    powershell -ExecutionPolicy ByPass -c "irm https://astral.sh/uv/install.ps1 | iex"

Dies lädt das offizielle Instalationsskript herunter und führt es anschließend aus.

Tip

Andere Installationsmethoden sind in der Dokumentation von uv zu finden. Dort ist auch beschrieben, wie ein Update von uv durch `uv self update` installiert werden kann. Und (sehr zu empfehlen) wie die Autovervollständigung von uv commands in der PowerShell aktiviert werden kann.

Nach einem neustart der PowerShell lässt sich uv direkt ausführen.

#### 3. Installation von excel2moodle

Mit uv kann nun excel2moodle installiert werden.

In der PowerShell folgendes ausführen:

    uv tool install excel2moodle

Note

Wenn ein neues Update von excel2moodle installiert werden soll, ist die möglich mit: uv tool upgrade excel2moodle

#### 4. Starten von excel2moodle

Sobald excel2moodle über uv installiert ist, kann es direkt ausgeführt werden.

Hierfür wieder eine PowerShell oder CMD öffnen und den folgenden Befehl ausführen:

    excel2moodle

## Fragensammlung in der Tabellenkalkulation erstellen

Um Fragen in der Exceltabelle zu erstellen sei hier auf die User Reference verwiesen. Dort sind alle tags erklärt, was sie bedeuten, für welchen Fragentyp sie ausgefüllt werden müssen und was zu beachten ist. Eine Sammlung an Beispielen von Fragen ist unter Fragenbeispiele zu finden.

## Export einer Fragen-Auswahl aus Excel2moodle

Um Fragen aus excel2moodle zu exportieren und für den Impot in Moodle vorzubereiten sind die Folgenden Schritte notwendig:

1. Auswahl der gewünschten Fragen durch anklicken: Wenn alle oder keine Fragen ausgewählt werden sollen, kann über der Fragenliste der Haken bei select all gesetzt, bzw. zurückgesetzt werden.

2. Überprüfen ob die Anzahl an Fragen und Gesamtpunkten richtig ist. Dies ist möglich oben rechts neben der Fragenliste im Bereich Selection

3. Export Dialog öffnen und Einstellungen wählen: Die folgenden Einstellungen können eingestellt werden. Excel2moodle merkt sich diese Einstellungen und übernimmt immer jene der letzten Sitzung Die Einstellungen werden im Export Dialog nach drücken des `export` Buttons gemacht. Siehe :ref: imgExportAuswahl

   - Fragenvariante für NFM Fragen wählen:

       Für den Fragentyp `NFM` werden mehrere Versionen der gleichen Numerischen Frage erstellt. In der Fragenliste wird jedoch nur eine Frage gelistet. Daher wird erst beim Export die Variante gewählt. Um nicht bei jeder Frage nachfragen zu müssen, kann eine standard Variante gewählt werden (Bsp. nr. 3). Wenn bei einer Frage es keine Vesion 3 gibt, wird nur bei dieser nachgefragt. Wenn keine Fragenvariante gewählt wird, bzw. Variante 0 gewählt ist, wird beim Export jeder einzelnen Frage ein dialog angezeigt zur Auswahl der Frage

   - Fragen kategorisiert exportieren:

       Excel2moodle bietet die Möglichkeit die Fragen kategorisiert zu exportieren oder nicht. Wenn die Fragen kategorisiert exportiert werden, werden diese in Moodle in den Kategorien einsortiert, wie sie auch in der Tabellenkalkulation sortiet sind. ( Wenn diese Kategorien in dem Moodle-Test nicht existieren, werden sie automatisch erstellt. )

   - Export Datei:

       Standartmäßig wird in die Datei `TestFile.xml` geschrieben. Wenn eine Andere Datei gewünscht ist, kann diese einfach gewählt werden, durch anklicken des Buttons zu sehen in :ref: imgExportAuswahl

Export der Fragenauswahl aus Excel2moodle

In Excel2moodle sind alle Fragen ausgewählt über die Checkbox über der Fragenliste. Oben sieht man die Anzahl an gewählten Fragen und die Summe der Punkte, die alle Fragen bei richtiger Beantwortung ergeben. Wenn auf den `export` butten gedrückt wird, öffnet sich der export Dialog, der nochmal die Anzahl an Punkten und Fragen zeigt. `Include Questions in Categories` ist nicht ausgewählt das bedeutet, dass die Kategorien nicht exportiert werden und in Moodle die Fragen nicht kategorisiert werden, sondern die Fragen in die zuletzt ausgewählte Kategorie importiert werden. Wenn dieser Haken gesetzt wird, werden die Fragen in den gleichen Kategorien in Moodle einsortiert, wie sie in der Tabellenkalkulation vorliegen.

## Import einer Fragensammlung in Moodle

Um eine Fragen Auswahl, die zuvor mit Excel2moodle erstellt wurde in Moodle zu importieren, sind die folgenden Schritte notwendig:

1. In dem Test-Element im Moodlekurs wird zu dem Reiter Fragensammlung navigiert.

2. Dort wird in dem Dropdown-Menu Oben Recht die Option `Import` ausgewählt.

3. Der Import-Typ muss `Moodle-xml` sein

4. Nun kann die Datei `*.xml` ausgewählt werden.

   Die Import Übersichtsseite im Moodle. Von Oben nach Unten müssen alle Gelb markierten Stellen ausgewählt werden

5. Nachdem der `Import` Button geklickt wurde, erscheint eine Übersicht über die importierten Fragen.

   Die Übersicht über alle importieren Fragen. Etwaige Fehler werden hier auch angezeigt

6. Wenn der Import in Moodle erfolgreich war, ist zu sehen, dass alle Fragen, die in dem How-to Export einer Fragen-Auswahl aus Excel2moodle (zu sehen in Export der Fragenauswahl aus Excel2moodle) exportiert wurden nun in Moodle verfügbar sind. Die Fragen sind einsortiert in die Kategorien KAT_01 und KAT_02

   Die Übersicht über die Fragenkategorien in Moodle. Die Kategorien KAT_01 und KAT_02 wurden automatisch beim Import erstellt. In Klammern hinter den Kategorien Namen sind die Anzahl an Fragen.

Note

Der Import erfolgt bei Moodle immer in die zuletzt ausgewählte Kategorie, wenn in der `*.xml` Datei keine Kategorien angegeben sind. Sobald bei excel2moodle die Fragen kategorisiert exportiert werden, sind die Kategorien enthalten. Wenn diese Kategorien im Moodle-Test bereits existieren, werden die Fragen in die existierenden Kategorien sortiert. Ansonsten werden die Kategorien angelegt.

## Creating an exam question selection

An exam most often will not include all questions present in the spreadsheet. Therefore only a selection of questions can be made with excel2moodle. The selection can be exported to a single `.xml` file, which then may be uploaded to moodle

Create an exam File:

> 1. click on every questions that should be included in the exam

> 2. check, if the total number of points and questions is as desired

> 3. Configure the export Settings to your liking. Possible is:

>    - Whether or not the questions should be categorized

>    - If for every `NFM` question the same variant should be used

>    - If yes, which variant this should be

> 4. Export the selected questions by clicking on `export selected questions to examfile`

> 5. You will be promted to specify the export location

Now a little overview is shown with the selected questions. If clicking OK those questions will be exported into the file specified at step 3

## Using the extra modules from the `Tools` section

Some functionality is separated from the main use-case, hence it lives outside the core subpackage inside the extra subpackage. Those functionality can be used either via cmd through the `excel2moodle.extra` subpackage and run as scripts, or it is accessible under the `Tools` section via the main window taskbar.

How to use the extra scripts or the tools counterpart is documented in the source-code documentation excel2moodle.extra package